@@ -60,12 +60,14 @@ using namespace std;
 // A hard-coded list of available files in the bankdata directory. In
 // the long run, this should be replaced by a dynamic lookup in
 // populate_dated_files(), but for now this is the easiest solution.
-const char* file_dates[] = {
-  "bankdata_20090907.txt",
-  "bankdata_20091207.txt",
-  0 // Important: The array has to end with the 0 entry,
-    // otherwise we have runaway and crash!
-};
+// const char* file_dates[] = {
+//   "bankdata_20090102.txt",
+//   "bankdata_20090203.txt",
+//   0 // Important: The array has to end with the 0 entry,
+//     // otherwise we have runaway and crash!
+// };
+#include "../bankdata/bankdatalist.h"
+// The array is now created at build time in the above file
 
 // A hard-coded replacement for strptime() because that one is not
 // available on windows/mingw.
