@@ -216,9 +216,8 @@ AccountNumberCheck::Result method_22(const int *account, int *weight) {
     return algo01(10, weight, false, 10, account);
 }
 AccountNumberCheck::Result method_23(const int *account, int *weight) {
-    number2Array("7654320", weight);
-    int tmp = algo03(11, weight, false, account, 0, 9);
-    tmp = tmp % 11;
+    number2Array("7654320000", weight);
+    int tmp = algo03(11, weight, false, account, 0, 5);
     if (0 == tmp && 0 == account[6])
 	return AccountNumberCheck::OK;
     if (1 == tmp && account[5] == account[6])
@@ -1427,7 +1426,7 @@ AccountNumberCheck::Result method_C5(const int *account, int *weight) {
     }
     return AccountNumberCheck::ERROR;
 }
-// method C6 was changed for due-date March, 9 2009
+// method C6 was last changed for due-date June, 6 2010
 // checked with Bundesbank-Testnumbers
 AccountNumberCheck::Result method_C6(const int *account, int *weight) {
     number2Array("0121212120", weight);
@@ -1438,6 +1437,7 @@ AccountNumberCheck::Result method_C6(const int *account, int *weight) {
 	case 0:	mod_factor=30;	break;	// prefix="4451970"
 	case 1:	mod_factor=33;	break;	// prefix="4451981"
 	case 2:	mod_factor=36;	break;	// prefix="4451992"
+	case 3:	mod_factor=38;	break;	// prefix="4451993"
 	case 7:	mod_factor=31;	break;	// prefix="5499570"
 	case 9:	mod_factor=40;	break;	// prefix="5499579"
 	default:
@@ -1482,14 +1482,17 @@ AccountNumberCheck::Result method_D0(const int *account, int *weight) {
     else
 	return AccountNumberCheck::OK;				// variant 2, "method 9" again :-))
 }
+// method D1 was modified with due date starting from 7. June 2010
 AccountNumberCheck::Result method_D1(const int *account, int *weight) {
-    if (account[0] == 0 || account[0] == 3 || account[0] == 9)
-	return AccountNumberCheck::ERROR;
-    // note: from here on this method is quite similar to method_C6
+    // note: this method is quite similar to method_C6
     number2Array("2121212120", weight);
     int result	= algo03(10, weight, true, account, 0, 8);
-    // quick hack: the processed leading numbers "428259" boil down to a constant factor of 29
-    result	+= 29;
+    // quick hack: the processed number-prefix "436338" or "428259" boils
+    //		   down to a constant factor
+    if (account[0] == 0 || ( account[0] >= 3 && account[0] <= 5 ) || account[0] == 9)
+	result	+= 31;	// prefix "436338" -> factor 31
+    else
+	result	+= 29;	// prefix "428259" -> factor 29
     // calc the check number, note: 1000 should be large enough.
     result	= (1000 - result) % 10;
     // compare the result with the real check number
@@ -1513,6 +1516,25 @@ AccountNumberCheck::Result method_D3(const int *account, int *weight) {
     return method_27(account,weight);				// variant 2
 }
 
+// new method D4 valid from June 7th, 2010, checked with Bundesbank-Testnumbers
+AccountNumberCheck::Result method_D4(const int *account, int *weight) {
+    // note this is a slightly modified version of the old method D1
+    if (( account[0] >= 0 && account[0] <= 2 ) || ( account[0] >= 6 && account[0] <= 8 ))
+        return AccountNumberCheck::ERROR;
+    // note: from here on this method is quite similar to method_C6
+    number2Array("2121212120", weight);
+    int result  = algo03(10, weight, true, account, 0, 8);
+    // quick hack: the processed leading numbers "428259" boil down to a constant factor of 29
+    result	+= 29;
+    // calc the check number, note: 1000 should be large enough.
+    result	= (1000 - result) % 10;
+    // compare the result with the real check number
+    if (account[9] == result)
+	return AccountNumberCheck::OK;
+    else
+	return AccountNumberCheck::ERROR;
+}
+
 struct method_func_s {
     const char *str;
     AccountNumberCheck::MethodFunc func;
@@ -1648,6 +1670,7 @@ const struct method_func_s cb_funcs[] = {
   { "D1", method_D1},
   { "D2", method_D2},
   { "D3", method_D3},
+  { "D4", method_D4},
   { 0, 0} // Important: The array has to end with the {0,0} entry,
 	  // otherwise initMethodMap() will runaway and crash!
 };
